# Easy-TongjiAPI

## 项目简介



本项目是同济大学教务系统的信息查询、课表操作、成绩查询等学生教务API的封装，以及登录教务系统等辅助功能的实现。

作者相信，借助本项目，任何一个有python基础的人都可以轻松完成换课、查询成绩等操作；而对那些对python较为熟练的人来说，使用本工具可以让他们如虎添翼，轻松完成自动查成绩、抢课、监视扩课等操作。

**在使用本工具时，请负起责任心。1系统不是你的后花园，请不要对1系统发出过量的请求。**

> 忘了那烦人的Cookie、headers和乱七八糟的接口和格式吧!

### 本项目是：

- 一个任何人都可以轻松使用的Python包
- 一个封装了基本教务功能API接口的工具
- 一个使你不用再去浏览器复制cookies的好帮手

### 本项目不是：

- 抢课工具
- 可以黑入一系统的神奇软件
- 技术力很强的作品



### 安装

项目会在未来发布到PyPI平台。

如果你需要现在使用，请clone项目到本地并直接import。



### 条款和条件

为了保护作者、规范使用，作者对本包的使用和二次开发作出了以下限制：

- 本项目使用GNU GENERAL PUBLIC LICENSE v3.0协议开源

- 豁免用户二次开发必须使用相同协议开源的条款。但是，如果你决定不使用相同协议二次开源，那么你将不得再继续使用项目中来自其他项目的使用该协议开源的代码。
- 用户二次开发的代码禁止用于商业盈利、网络攻击、网络犯罪等目的



## 有偿招募

### 验证码耗时

统一身份验证系统要求必须提交验证码答案。作者由于能力有限，目前仅能使用打码平台完成此目标；但是这样的后果就是单次登陆的时间被延长至十秒以上，且需要支付一定的费用。如果你可以以任何方法帮助把这一耗时显著减小（且不过度耗费客户端性能），作者愿意为你的贡献支付一定的酬金（100~200r），且相关代码可以以你的身份PR。

